@@ -1,12 +1,10 @@
-use {
-    lazy_static::lazy_static,
-    solana_sdk::{
-        clock::Slot,
-        hash::{Hash, Hasher},
-        pubkey::Pubkey,
-    },
-    std::collections::{HashMap, HashSet},
+use lazy_static::lazy_static;
+use solana_sdk::{
+    clock::Slot,
+    hash::{Hash, Hasher},
+    pubkey::Pubkey,
 };
+use std::collections::{HashMap, HashSet};
 
 pub mod instructions_sysvar_enabled {
     solana_sdk::declare_id!("EnvhHCLvg55P7PDtbvR1NwuTuAeodqpusV3MR5QEK8gs");
@@ -242,15 +240,15 @@ pub mod remove_native_loader {
 }
 
 pub mod return_data_syscall_enabled {
-    solana_sdk::declare_id!("DwScAzPUjuv65TMbDnFY7AgwmotzWy3xpEJMXM3hZFaB");
+    solana_sdk::declare_id!("BJVXq6NdLC7jCDGjfqJv7M1XHD4Y13VrpDqRF2U7UBcC");
 }
 
 pub mod sol_log_data_syscall_enabled {
-    solana_sdk::declare_id!("6uaHcKPGUy4J7emLBgUTeufhJdiwhngW6a1R9B7c2ob9");
+    solana_sdk::declare_id!("HYPs7jyJ3KwQFdDpuSzMtVKf1MLJDaZRv3CSWvfUqdFo");
 }
 
 pub mod ed25519_program_enabled {
-    solana_sdk::declare_id!("6ppMXNYLhVd7GcsZ5uV11wQEW7spppiMVfqQv5SXhDpX");
+    solana_sdk::declare_id!("E1TvTNipX8TKNHrhRC8SMuAwQmGY58TZ4drdztP3Gxwc");
 }
 
 pub mod requestable_heap_size {
@@ -261,10 +259,6 @@ pub mod add_compute_budget_program {
     solana_sdk::declare_id!("4d5AKtxoh93Dwm1vHXUU3iRATuMndx1c431KgT2td52r");
 }
 
-pub mod spl_token_v3_3_0_release {
-    solana_sdk::declare_id!("Ftok2jhqAqxUWEiCVRrfRs9DPppWP8cgTB7NQNKL88mS");
-}
-
 pub mod reject_deployment_of_unresolved_syscalls {
     solana_sdk::declare_id!("DqniU3MfvdpU3yhmNF1RKeaM5TZQELZuyFGosASRVUoy");
 }
@@ -273,8 +267,8 @@ pub mod reject_section_virtual_address_file_offset_mismatch {
     solana_sdk::declare_id!("5N4NikcJLEiZNqwndhNyvZw15LvFXp1oF7AJQTNTZY5k");
 }
 
-pub mod reject_non_rent_exempt_vote_withdraws {
-    solana_sdk::declare_id!("7txXZZD6Um59YoLMF7XUNimbMjsqsWhc7g2EniiTrmp1");
+pub mod reject_all_elf_rw {
+    solana_sdk::declare_id!("DeMpxgMq51j3rZfNK2hQKZyXknQvqevPSFPJFNTbXxsS");
 }
 
 lazy_static! {
@@ -342,10 +336,9 @@ lazy_static! {
         (ed25519_program_enabled::id(), "enable builtin ed25519 signature verify program"),
         (requestable_heap_size::id(), "Requestable heap frame size"),
         (add_compute_budget_program::id(), "Add compute_budget_program"),
-        (spl_token_v3_3_0_release::id(), "spl-token v3.3.0 release"),
         (reject_deployment_of_unresolved_syscalls::id(), "Reject deployment of programs with unresolved syscall symbols"),
         (reject_section_virtual_address_file_offset_mismatch::id(), "enforce section virtual addresses and file offsets in ELF to be equal"),
-        (reject_non_rent_exempt_vote_withdraws::id(), "fail vote withdraw instructions which leave the account non-rent-exempt"),
+        (reject_all_elf_rw::id(), "reject all read-write data in program elfs"),
         /*************** ADD NEW FEATURES HERE ***************/
     ]
     .iter()
